pub struct CrawlerConfig {
pub request_max_retries: usize,
pub task_max_errors: usize,
pub module_max_errors: usize,
pub module_locker_ttl: u64,
pub node_id: Option<String>,
pub task_concurrency: Option<usize>,
pub publish_concurrency: Option<usize>,
pub parser_concurrency: Option<usize>,
pub error_task_concurrency: Option<usize>,
pub backpressure_retry_delay_ms: Option<u64>,
pub dedup_ttl_secs: Option<u64>,
pub idle_stop_secs: Option<u64>,
}Expand description
Crawler Configuration
Fields
request_max_retries: usizeMaximum retries for failed requests
task_max_errors: usizeMaximum allowed errors per task
module_max_errors: usizeMaximum allowed errors per module
module_locker_ttl: u64TTL for module locks
node_id: Option<String>Optional node ID (useful for stable node identity across restarts)
task_concurrency: Option<usize>Concurrency for task processor (JS execution)
publish_concurrency: Option<usize>Concurrency for request publishing
parser_concurrency: Option<usize>Concurrency for parser task processor
error_task_concurrency: Option<usize>Concurrency for error task processor
backpressure_retry_delay_ms: Option<u64>Delay in milliseconds before retrying when backpressure is detected
dedup_ttl_secs: Option<u64>Request deduplication TTL in seconds (default: 3600)
idle_stop_secs: Option<u64>Idle stop timeout in seconds (stop engine if local queues have no data for this duration)